# Generated by Django 3.2.13 on 2022-05-19 03:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_omise', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='card',
            name='fingerprint',
            field=models.TextField(blank=True),
        ),
    ]



import json

from django.contrib import admin
from django.utils.html import format_html

# Register your models here.
from .models.core import Customer, Card, Charge, Source, Refund
from .models.event import Event


class CardInline(admin.TabularInline):

    model = Card

    fields = (
        "id",
        "last_digits",
        "deleted",
    )

    extra = 0

    def has_change_permission(self, request, obj=None):
        return False


class ChargeInline(admin.StackedInline):

    model = Charge
    extra = 0
    can_delete = False

    def has_change_permission(self, request, obj=None):
        return False


@admin.register(Customer)
class CustomerAdmin(admin.ModelAdmin):

    search_fields = (
        "user__email",
        "user__username",
        "id",
    )

    list_display = (
        "id",
        "deleted",
        "user",
        "livemode",
        "date_created",
        "date_updated",
    )

    readonly_fields = ("uid",)

    inlines = [
        CardInline,
        ChargeInline,
    ]

    list_filter = (
        "livemode",
        "date_created",
        "date_updated",
        "deleted",
    )


@admin.register(Card)
class CardAdmin(admin.ModelAdmin):
    list_display = (
        "customer",
        "id",
        "livemode",
        "last_digits",
        "deleted",
        "date_created",
        "date_updated",
    )
    list_filter = (
        "livemode",
        "deleted",
        "date_created",
        "date_updated",
    )

    readonly_fields = ("uid",)
    search_fields = ("customer__user__email", "customer__user__username", "id")

    inlines = [
        ChargeInline,
    ]


@admin.register(Refund)
class RefundAdmin(admin.ModelAdmin):
    list_display = (
        "id",
        "livemode",
        "date_created",
        "charge",
        "amount",
        "currency",
        "funding_amount",
        "funding_currency",
        "voided",
    )
    list_filter = (
        "livemode",
        "date_created",
        "date_updated",
        "voided",
    )
    search_fields = [
        "charge__id",
    ]

    def has_change_permission(self, request, obj=None):
        return False


@admin.register(Event)
class EventAdmin(admin.ModelAdmin):
    list_display = (
        "id",
        "livemode",
        "event_type",
        "date_created",
    )
    readonly_fields = (
        "uid",
        "event_object",
        "content_type",
        "object_id",
    )
    list_filter = ("livemode", "date_created", "date_updated", "event_type")

    fields = (
        "id",
        "livemode",
        "event_type",
        "event_data",
        "uid",
        "event_object",
        "content_type",
        "object_id",
    )

    def event_data(self, obj=None):
        return format_html("<pre>{}</pre>", json.dumps(obj.data, indent=4))

    def has_change_permission(self, request, obj=None):
        return False


class RefundInline(admin.StackedInline):
    model = Refund

    extra = 0

    def has_change_permission(self, request, obj=None):
        return False


@admin.register(Charge)
class ChargeAdmin(admin.ModelAdmin):
    search_fields = ("id",)

    def has_change_permission(self, request, obj=None):
        return False

    list_display = (
        "id",
        "livemode",
        "status",
        "date_created",
        "date_updated",
        "amount",
        # "authorize_uri",
        "authorized",
        "capturable",
        "capture",
        # "card",
        "currency",
        # "customer",
        "description",
        "disputable",
        "expired",
        "expired_at",
        "expires_at",
        "failure_code",
        "failure_message",
        "fee",
        "fee_vat",
        "funding_amount",
        "funding_currency",
        "interest",
        "interest_vat",
        "ip",
        "net",
        "paid",
        "paid_at",
        "refundable",
        "refunded_amount",
        "reversed",
        # "source",
        "voided",
        "zero_interest_installments",
    )
    list_filter = (
        "livemode",
        "date_created",
        "date_updated",
        "authorized",
        "capturable",
        "capture",
        "disputable",
        "expired",
        "expired_at",
        "expires_at",
        "paid",
        "paid_at",
        "refundable",
        "reversed",
        "voided",
        "zero_interest_installments",
    )

    inlines = [
        RefundInline,
    ]

    readonly_fields = ("uid",)


@admin.register(Source)
class SourceAdmin(admin.ModelAdmin):
    list_display = (
        "id",
        "amount",
        "bank",
        "barcode",
        "charge_status",
        "currency",
        "email",
        "flow",
        "installment_term",
        "mobile_number",
        "name",
        "phone_number",
        "platform_type",
        "receipt_amount",
        "store_id",
        "store_name",
        "terminal_id",
        "type",
        "zero_interest_installments",
    )
    list_filter = ("zero_interest_installments",)
    search_fields = (
        "id",
        "name",
    )
    readonly_fields = ("uid",)

    def has_change_permission(self, request, obj=None):
        return False



# Generated by Django 3.2.13 on 2022-05-18 19:20

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('contenttypes', '0002_remove_content_type_name'),
    ]

    operations = [
        migrations.CreateModel(
            name='Card',
            fields=[
                ('id', models.CharField(max_length=255, primary_key=True, serialize=False)),
                ('livemode', models.BooleanField()),
                ('data', models.JSONField(blank=True, default=dict)),
                ('date_created', models.DateTimeField(auto_now_add=True)),
                ('date_updated', models.DateTimeField(auto_now=True)),
                ('uid', models.UUIDField(default=uuid.uuid4, editable=False, unique=True)),
                ('name', models.CharField(blank=True, max_length=255)),
                ('phone_number', models.CharField(blank=True, max_length=255)),
                ('postal_code', models.CharField(blank=True, max_length=255)),
                ('state', models.CharField(blank=True, max_length=255)),
                ('street1', models.CharField(blank=True, max_length=255)),
                ('street2', models.CharField(blank=True, max_length=255)),
                ('tokenization_method', models.CharField(blank=True, max_length=255)),
                ('first_digits', models.CharField(blank=True, max_length=6)),
                ('last_digits', models.CharField(max_length=4)),
                ('bank', models.CharField(blank=True, max_length=255)),
                ('brand', models.CharField(blank=True, max_length=255)),
                ('city', models.CharField(blank=True, max_length=255)),
                ('country', models.CharField(blank=True, max_length=255)),
                ('expiration_month', models.CharField(blank=True, max_length=2)),
                ('expiration_year', models.CharField(blank=True, max_length=4)),
                ('financing', models.CharField(blank=True, max_length=10)),
                ('deleted', models.BooleanField(default=False, help_text='Whethe this card was deleted.')),
            ],
            options={
                'ordering': ['-date_created'],
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Source',
            fields=[
                ('id', models.CharField(max_length=255, primary_key=True, serialize=False)),
                ('livemode', models.BooleanField()),
                ('data', models.JSONField(blank=True, default=dict)),
                ('date_created', models.DateTimeField(auto_now_add=True)),
                ('date_updated', models.DateTimeField(auto_now=True)),
                ('uid', models.UUIDField(default=uuid.uuid4, editable=False, unique=True)),
                ('amount', models.IntegerField(help_text='Source amount in smallest unit of source currency')),
                ('bank', models.CharField(blank=True, max_length=255)),
                ('barcode', models.CharField(blank=True, help_text='Source amount in smallest unit of source currency', max_length=255)),
                ('charge_status', models.CharField(choices=[('failed', 'Failed'), ('expired', 'Expired'), ('pending', 'Pending'), ('reverse', 'Reversed'), ('successful', 'Successful'), ('unknown', 'Unknown')], help_text='Status of charge created using this source (if any)', max_length=10)),
                ('currency', models.CharField(choices=[('USD', 'United States Dollar'), ('THB', 'Thai Baht'), ('SGD', 'Singapore Dollar'), ('JPY', 'Japanese Yen'), ('GBP', 'Pound Sterling'), ('EUR', 'Euro'), ('CNY', 'Chinese Yuan'), ('AUD', 'Australian Dollar')], max_length=3)),
                ('email', models.CharField(blank=True, help_text="The payer's email", max_length=255)),
                ('flow', models.CharField(choices=[('redirect', 'Redirect'), ('offline', 'Offline'), ('app_redirect', 'App Redirect')], help_text='The payment flow payers need to go through to complete the payment. One of redirect, offline, or app_redirect', max_length=50)),
                ('installment_term', models.IntegerField(blank=True, help_text='Installment term in months', null=True)),
                ('mobile_number', models.CharField(blank=True, max_length=50)),
                ('name', models.CharField(blank=True, help_text="Payer's name", max_length=255)),
                ('phone_number', models.CharField(blank=True, max_length=50)),
                ('platform_type', models.CharField(blank=True, help_text='Platform from which payer is making a payment. One of WEB, IOS, or ANDROID', max_length=50)),
                ('receipt_amount', models.IntegerField(blank=True, null=True)),
                ('store_id', models.CharField(blank=True, max_length=255)),
                ('store_name', models.CharField(blank=True, max_length=255)),
                ('terminal_id', models.CharField(blank=True, max_length=255)),
                ('type', models.CharField(choices=[('truemoney', 'TrueMoney Wallet'), ('internet_banking_bay', 'Krungsri Bank'), ('internet_banking_bbl', 'Bangkok Bank'), ('internet_banking_ktb', 'Krungthai Bank'), ('internet_banking_scb', 'SCB Bank'), ('promptpay', 'Promptpay')], max_length=255)),
                ('zero_interest_installments', models.BooleanField(blank=True, null=True)),
            ],
            options={
                'ordering': ['-date_created'],
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Event',
            fields=[
                ('id', models.CharField(max_length=255, primary_key=True, serialize=False)),
                ('livemode', models.BooleanField()),
                ('date_created', models.DateTimeField(auto_now_add=True)),
                ('date_updated', models.DateTimeField(auto_now=True)),
                ('uid', models.UUIDField(default=uuid.uuid4, editable=False, unique=True)),
                ('event_type', models.CharField(choices=[('card.destroy', 'CARD_DESTROY'), ('card.update', 'CARD_UPDATE'), ('charge.capture', 'CHARGE_CAPTURE'), ('charge.complete', 'CHARGE_COMPLETE'), ('charge.create', 'CHARGE_CREATE'), ('charge.expire', 'CHARGE_EXPIRE'), ('charge.reverse', 'CHARGE_REVERSE'), ('charge.update', 'CHARGE_UPDATE'), ('customer.create', 'CUSTOMER_CREATE'), ('customer.destroy', 'CUSTOMER_DESTROY'), ('customer.update', 'CUSTOMER_UPDATE'), ('customer.update.card', 'CUSTOMER_UPDATE_CARD'), ('dispute.accept', 'DISPUTE_ACCEPT'), ('dispute.close', 'DISPUTE_CLOSE'), ('dispute.create', 'DISPUTE_CREATE'), ('dispute.update', 'DISPUTE_UPDATE'), ('link.create', 'LINK_CREATE'), ('recipient.activate', 'RECIPIENT_ACTIVATE'), ('recipient.create', 'RECIPIENT_CREATE'), ('recipient.deactivate', 'RECIPIENT_DEACTIVATE'), ('recipient.destroy', 'RECIPIENT_DESTROY'), ('recipient.update', 'RECIPIENT_UPDATE'), ('recipient.verify', 'RECIPIENT_VERIFY'), ('refund.create', 'REFUND_CREATE'), ('schedule.create', 'SCHEDULE_CREATE'), ('schedule.destroy', 'SCHEDULE_DESTROY'), ('schedule.expire', 'SCHEDULE_EXPIRE'), ('schedule.expiring', 'SCHEDULE_EXPIRING'), ('schedule.suspend', 'SCHEDULE_SUSPEND'), ('transfer.create', 'TRANSFER_CREATE'), ('transfer.destroy', 'TRANSFER_DESTROY'), ('transfer.fail', 'TRANSFER_FAIL'), ('transfer.pay', 'TRANSFER_PAY'), ('transfer.send', 'TRANSFER_SEND'), ('transfer.update', 'TRANSFER_UPDATE')], max_length=50)),
                ('data', models.JSONField(default=dict)),
                ('object_id', models.CharField(blank=True, max_length=255, null=True)),
                ('content_type', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='contenttypes.contenttype')),
            ],
        ),
        migrations.CreateModel(
            name='Customer',
            fields=[
                ('id', models.CharField(max_length=255, primary_key=True, serialize=False)),
                ('livemode', models.BooleanField()),
                ('data', models.JSONField(blank=True, default=dict)),
                ('date_created', models.DateTimeField(auto_now_add=True)),
                ('date_updated', models.DateTimeField(auto_now=True)),
                ('uid', models.UUIDField(default=uuid.uuid4, editable=False, unique=True)),
                ('deleted', models.BooleanField(default=False, help_text='Whether this customer was deleted.')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='omise_customers', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['-date_created'],
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Charge',
            fields=[
                ('id', models.CharField(max_length=255, primary_key=True, serialize=False)),
                ('livemode', models.BooleanField()),
                ('data', models.JSONField(blank=True, default=dict)),
                ('date_created', models.DateTimeField(auto_now_add=True)),
                ('date_updated', models.DateTimeField(auto_now=True)),
                ('uid', models.UUIDField(default=uuid.uuid4, editable=False, unique=True)),
                ('status', models.CharField(choices=[('failed', 'Failed'), ('expired', 'Expired'), ('pending', 'Pending'), ('reverse', 'Reversed'), ('successful', 'Successful'), ('unknown', 'Unknown')], help_text='Status of this charge.', max_length=10)),
                ('amount', models.IntegerField(help_text='Charge amount in the smallest unit of charge currency')),
                ('authorize_uri', models.CharField(blank=True, help_text='URI for payment authorization (e.g. 3-D Secure).', max_length=255)),
                ('authorized', models.BooleanField(blank=True, help_text='Whether charge has been authorized.', null=True)),
                ('capturable', models.BooleanField(blank=True, help_text='Whether charge is able to be captured (paid).', null=True)),
                ('capture', models.BooleanField(blank=True, help_text='Whether charge is set to be automatically captured (paid).', null=True)),
                ('currency', models.CharField(choices=[('USD', 'United States Dollar'), ('THB', 'Thai Baht'), ('SGD', 'Singapore Dollar'), ('JPY', 'Japanese Yen'), ('GBP', 'Pound Sterling'), ('EUR', 'Euro'), ('CNY', 'Chinese Yuan'), ('AUD', 'Australian Dollar')], max_length=3)),
                ('description', models.TextField(blank=True)),
                ('disputable', models.BooleanField(blank=True, null=True)),
                ('expired', models.BooleanField(blank=True, help_text='Whether this charge has expired.', null=True)),
                ('expired_at', models.DateTimeField(blank=True, null=True)),
                ('expires_at', models.DateTimeField(blank=True, null=True)),
                ('failure_code', models.CharField(blank=True, max_length=255)),
                ('failure_message', models.TextField(blank=True)),
                ('fee', models.IntegerField()),
                ('fee_vat', models.IntegerField()),
                ('funding_amount', models.IntegerField(blank=True, help_text='For multi-currency charges, amount after exchange into account funding currency.', null=True)),
                ('funding_currency', models.CharField(choices=[('USD', 'United States Dollar'), ('THB', 'Thai Baht'), ('SGD', 'Singapore Dollar'), ('JPY', 'Japanese Yen'), ('GBP', 'Pound Sterling'), ('EUR', 'Euro'), ('CNY', 'Chinese Yuan'), ('AUD', 'Australian Dollar')], max_length=3)),
                ('interest', models.IntegerField(blank=True, help_text='Interest paid by customer or merchant over the course of an installment term.', null=True)),
                ('interest_vat', models.IntegerField(blank=True, help_text='Value-added Tax (VAT) applied to interest.', null=True)),
                ('ip', models.CharField(blank=True, help_text='IP address provided to Omise at charge creation. May be IPv4 or IPv6.', max_length=255)),
                ('metadata', models.JSONField(blank=True, default=dict, help_text='Custom metadata for this charge.')),
                ('net', models.IntegerField(help_text='funding_amount after fees, interest, and VAT deducted.')),
                ('paid', models.BooleanField(help_text='Whether charge has been captured (paid).')),
                ('paid_at', models.DateTimeField(blank=True, null=True)),
                ('refundable', models.BooleanField(help_text='Whether charge is able to be refunded.')),
                ('refunded_amount', models.IntegerField(blank=True, help_text='Refunded amount in smallest unit of currency.', null=True)),
                ('return_uri', models.TextField(blank=True, help_text='URI to which customer is redirected after 3-D Secure card authorization or other redirect-based authorization.')),
                ('reversed', models.BooleanField(blank=True, help_text='Whether charge authorization is able to be reversed.', null=True)),
                ('voided', models.BooleanField(blank=True, help_text='Whether, in the case of a refund, charge was voided instead. Charges are voided if refund is processed before settlement time.', null=True)),
                ('zero_interest_installments', models.BooleanField(blank=True, help_text='Whether merchant absorbs the interest for installment payments; must match value in associated source.', null=True)),
                ('card', models.ForeignKey(blank=True, help_text='Card that was charged (if card was charged).', null=True, on_delete=django.db.models.deletion.PROTECT, related_name='charges', to='django_omise.card')),
                ('customer', models.ForeignKey(blank=True, help_text='Customer associated with charge.', null=True, on_delete=django.db.models.deletion.PROTECT, related_name='charges', to='django_omise.customer')),
                ('source', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='charges', to='django_omise.source')),
            ],
            options={
                'ordering': ['-date_created'],
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='card',
            name='customer',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='cards', to='django_omise.customer'),
        ),
        migrations.AddIndex(
            model_name='event',
            index=models.Index(fields=['content_type', 'object_id'], name='django_omis_content_80fefa_idx'),
        ),
    ]



# Generated by Django 3.2.13 on 2022-05-19 13:50

from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('django_omise', '0002_card_fingerprint'),
    ]

    operations = [
        migrations.CreateModel(
            name='Refund',
            fields=[
                ('id', models.CharField(max_length=255, primary_key=True, serialize=False)),
                ('livemode', models.BooleanField()),
                ('data', models.JSONField(blank=True, default=dict)),
                ('date_created', models.DateTimeField(auto_now_add=True)),
                ('date_updated', models.DateTimeField(auto_now=True)),
                ('uid', models.UUIDField(default=uuid.uuid4, editable=False, unique=True)),
                ('amount', models.IntegerField(help_text='Refund amount in smallest unit of charge currency.')),
                ('currency', models.CharField(choices=[('USD', 'United States Dollar'), ('THB', 'Thai Baht'), ('SGD', 'Singapore Dollar'), ('JPY', 'Japanese Yen'), ('GBP', 'Pound Sterling'), ('EUR', 'Euro'), ('CNY', 'Chinese Yuan'), ('AUD', 'Australian Dollar')], max_length=3)),
                ('funding_amount', models.IntegerField(blank=True, help_text='For multi-currency charges, amount after exchange into account funding currency.', null=True)),
                ('funding_currency', models.CharField(choices=[('USD', 'United States Dollar'), ('THB', 'Thai Baht'), ('SGD', 'Singapore Dollar'), ('JPY', 'Japanese Yen'), ('GBP', 'Pound Sterling'), ('EUR', 'Euro'), ('CNY', 'Chinese Yuan'), ('AUD', 'Australian Dollar')], max_length=3)),
                ('metadata', models.JSONField(blank=True, default=dict, help_text='Custom metadata for this refund.')),
                ('voided', models.BooleanField()),
                ('charge', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='refunds', to='django_omise.charge')),
            ],
            options={
                'ordering': ['-date_created'],
                'abstract': False,
            },
        ),
    ]
